@@ -176,6 +176,8 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
     long value_first        = 0;
     char pressure_units[10] = {0,};
     size_t pressure_units_len = 10;
+    long productionStatusOfProcessedData = 0;
+    bool is_tigge = false;
 
     double v;
 
@@ -188,6 +190,10 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
     if ((ret = grib_get_string_internal(hand, self->pressure_units, pressure_units, &pressure_units_len)) != GRIB_SUCCESS)
         return ret;
 
+    if ((ret = grib_get_long(hand, "productionStatusOfProcessedData", &productionStatusOfProcessedData)) != GRIB_SUCCESS)
+        return ret;
+    is_tigge = (productionStatusOfProcessedData==4 || productionStatusOfProcessedData==5);
+
     if (value_first == GRIB_MISSING_LONG) {
         *val = 0;
         return GRIB_SUCCESS;
@@ -200,9 +206,13 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
     v = value_first;
 
     if (scale_first != GRIB_MISSING_LONG) {
-        // GRIB-637 Potential vorticity surface
+        // GRIB-637, ECC-1081: Potential vorticity surface
         if (type_first == 109) {
-            scale_first -= 6;
+            if (is_tigge) {
+                scale_first -= 6; // TIGGE data follows different rules
+            } else {
+                scale_first -= 9;
+            }
         }
 
         while (scale_first < 0 && v != 0) {
@@ -303,9 +313,10 @@ static int pack_long(grib_accessor* a, const long* val, size_t* len)
     long value_first        = *val;
     long scale_first        = 0;
     long type_first         = 0;
-    long levelFactor        = 1;
     char pressure_units[10] = {0,};
     size_t pressure_units_len = 10;
+    bool is_tigge = false;
+    long productionStatusOfProcessedData = 0;
 
     grib_accessor_g2level* self = (grib_accessor_g2level*)a;
     grib_handle* hand           = grib_handle_of_accessor(a);
@@ -329,17 +340,23 @@ static int pack_long(grib_accessor* a, const long* val, size_t* len)
     if ((ret = grib_get_string_internal(hand, self->pressure_units, pressure_units, &pressure_units_len)) != GRIB_SUCCESS)
         return ret;
 
+    if ((ret = grib_get_long(hand, "productionStatusOfProcessedData", &productionStatusOfProcessedData)) != GRIB_SUCCESS)
+        return ret;
+    is_tigge = (productionStatusOfProcessedData==4 || productionStatusOfProcessedData==5);
+
     switch (type_first) {
         case 100: // Pa
             scale_first = 0;
             if (!strcmp(pressure_units, "hPa"))
                 value_first *= 100;
             break;
-        case 109:
-            if ((ret = grib_get_long(hand, "levelFactor", &levelFactor)) == GRIB_SUCCESS) {
-                // See ECC-1081
-                scale_first = levelFactor;
+        case 109: // Potential vorticity surface
+            if (!is_tigge) {
+                scale_first = 9;
+            } else {
+                scale_first = 6; // TIGGE data follows different rules
             }
+            break;
 
         default:
             break;
