@@ -16,43 +16,47 @@
 #ifndef grib_api_internal_H
 #define grib_api_internal_H
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /* cmake config header */
 #ifdef HAVE_ECCODES_CONFIG_H
-#include "eccodes_config.h"
+ #include "eccodes_config.h"
 #endif
 
 /* autoconf config header */
 #ifdef HAVE_CONFIG_H
-#include "config.h"
-#ifdef _LARGE_FILES
-#undef _LARGE_FILE_API
-#endif
+ #include "config.h"
+ #ifdef _LARGE_FILES
+  #undef _LARGE_FILE_API
+ #endif
 #endif
 
 #ifndef GRIB_INLINE
-#define GRIB_INLINE
+ #define GRIB_INLINE
 #endif
 
 /* See ECC-670 */
 #if IS_BIG_ENDIAN
-#if GRIB_MEM_ALIGN
-#define FAST_BIG_ENDIAN 1
-#else
-#define FAST_BIG_ENDIAN 0
-#endif
+ #if GRIB_MEM_ALIGN
+  #define FAST_BIG_ENDIAN 1
+ #else
+  #define FAST_BIG_ENDIAN 0
+ #endif
 #endif
 
 #if IEEE_BE
-#define IEEE
+ #define IEEE
 #else
-#if IEEE_LE
-#define IEEE
+ #if IEEE_LE
+  #define IEEE
+ #endif
 #endif
+
+#if defined(_WIN32) && defined(_MSC_VER)
+  #define _CRT_SECURE_NO_WARNINGS
+  #define _CRT_NONSTDC_NO_DEPRECATE
 #endif
 
 #include <stdio.h>
@@ -62,48 +66,46 @@ extern "C" {
 #include "eccodes_windef.h"
 
 #ifndef ECCODES_ON_WINDOWS
-#include <dirent.h>
-#include <unistd.h>
-#include <inttypes.h>
-#define ecc_snprintf snprintf
+ #include <dirent.h>
+ #include <unistd.h>
+ #include <inttypes.h>
 #else
-#include <direct.h>
-#include <io.h>
+ #define strtok_r strtok_s
+ #include <direct.h>
+ #include <io.h>
 
-/* Replace C99/Unix rint() for Windows Visual C++ (only before VC++ 2013 versions) */
-#if defined _MSC_VER && _MSC_VER < 1800
-double rint(double x);
-#endif
+ /* Replace C99/Unix rint() for Windows Visual C++ (only before VC++ 2013 versions) */
+ #if defined _MSC_VER && _MSC_VER < 1800
+  double rint(double x);
+ #endif
 
-#ifndef S_ISREG
-#define S_ISREG(mode) (mode & S_IFREG)
-#endif
+ #ifndef S_ISREG
+  #define S_ISREG(mode) (mode & S_IFREG)
+ #endif
 
-#ifndef S_ISDIR
-#define S_ISDIR(mode) (mode & S_IFDIR)
-#endif
+ #ifndef S_ISDIR
+  #define S_ISDIR(mode) (mode & S_IFDIR)
+ #endif
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif
+ #ifndef M_PI
+  #define M_PI 3.14159265358979323846
+ #endif
 
-#define R_OK 04 /* Needed for Windows */
+ #define R_OK 04 /* Needed for Windows */
 
-#ifndef F_OK
-#define F_OK 0
-#endif
+ #ifndef F_OK
+  #define F_OK 0
+ #endif
 
-#define mkdir(dirname, mode) _mkdir(dirname)
+ #define mkdir(dirname, mode) _mkdir(dirname)
 
-#ifdef _MSC_VER
-#define access(path, mode) _access(path, mode)
-#define chmod(path, mode) _chmod(path, mode)
-#define strdup(str) _strdup(str)
-#endif
+ #ifdef _MSC_VER
+  #define access(path, mode) _access(path, mode)
+  #define chmod(path, mode) _chmod(path, mode)
+  #define strdup(str) _strdup(str)
+ #endif
 
-#define ecc_snprintf _snprintf
-
-#endif
+#endif /* ifndef ECCODES_ON_WINDOWS */
 
 
 #include <limits.h>
@@ -113,9 +115,9 @@ double rint(double x);
 
 
 #ifdef HAVE_STRING_H
-#include <string.h>
+ #include <string.h>
 #else
-#include <strings.h>
+ #include <strings.h>
 #endif
 
 /*
@@ -198,7 +200,7 @@ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr, int type);
 #endif
 
 /* Return true if two strings are equal */
-#define STR_EQ(a, b) (strcmp((a), (b)) == 0)
+#define STR_EQUAL(a, b) (strcmp((a), (b)) == 0)
 
 #include "grib_api.h"
 
@@ -250,6 +252,8 @@ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr, int type);
 #define GRIB_COMPARE_NAMES (1 << 0)
 #define GRIB_COMPARE_TYPES (1 << 1)
 
+extern const int max_nbits;
+
 typedef struct grib_expression grib_expression;
 typedef struct grib_arguments grib_arguments;
 
@@ -305,14 +309,16 @@ typedef long (*iterator_has_next_proc)(grib_iterator* i);
 typedef int (*grib_pack_proc)(grib_handle* h, const double* in, size_t inlen, void* out, size_t* outlen);
 typedef int (*grib_unpack_proc)(grib_handle* h, const void* in, size_t inlen, double* out, size_t* outlen);
 
-
 typedef void (*accessor_destroy_proc)(grib_context*, grib_accessor*);
 
 typedef int (*accessor_unpack_long_proc)(grib_accessor*, long*, size_t* len);
 typedef int (*accessor_unpack_double_proc)(grib_accessor*, double*, size_t* len);
+typedef int (*accessor_unpack_float_proc)(grib_accessor*, float*, size_t* len);
 
 typedef int (*accessor_unpack_double_element_proc)(grib_accessor*, size_t, double*);
+typedef int (*accessor_unpack_float_element_proc)(grib_accessor*, size_t, float*);
 typedef int (*accessor_unpack_double_element_set_proc)(grib_accessor*, const size_t*, size_t, double*);
+typedef int (*accessor_unpack_float_element_set_proc)(grib_accessor*, const size_t*, size_t, float*);
 
 typedef int (*accessor_unpack_double_subarray_proc)(grib_accessor*, double*, size_t, size_t);
 typedef int (*accessor_unpack_string_proc)(grib_accessor*, char*, size_t* len);
@@ -332,6 +338,7 @@ typedef int (*accessor_pack_missing_proc)(grib_accessor*);
 typedef int (*accessor_pack_is_missing_proc)(grib_accessor*);
 typedef int (*accessor_pack_long_proc)(grib_accessor*, const long*, size_t* len);
 typedef int (*accessor_pack_double_proc)(grib_accessor*, const double*, size_t* len);
+typedef int (*accessor_pack_float_proc)(grib_accessor*, const float*, size_t* len);
 typedef int (*accessor_pack_string_proc)(grib_accessor*, const char*, size_t* len);
 typedef int (*accessor_pack_string_array_proc)(grib_accessor*, const char**, size_t* len);
 typedef int (*accessor_pack_bytes_proc)(grib_accessor*, const unsigned char*, size_t* len);
@@ -954,7 +961,9 @@ struct grib_accessor_class
     accessor_unpack_long_proc unpack_long;
 
     accessor_pack_double_proc pack_double;
+    accessor_pack_float_proc pack_float;
     accessor_unpack_double_proc unpack_double;
+    accessor_unpack_float_proc unpack_float;
 
     accessor_pack_string_proc pack_string;
     accessor_unpack_string_proc unpack_string;
@@ -977,7 +986,9 @@ struct grib_accessor_class
     accessor_next_proc next;
     accessor_compare_proc compare;
     accessor_unpack_double_element_proc unpack_double_element;
+    accessor_unpack_float_element_proc unpack_float_element;
     accessor_unpack_double_element_set_proc unpack_double_element_set;
+    accessor_unpack_float_element_set_proc unpack_float_element_set;
     accessor_unpack_double_subarray_proc unpack_double_subarray;
     accessor_clear_proc clear;
     accessor_clone_proc make_clone;
@@ -1267,7 +1278,7 @@ struct grib_int_array
     int* el;
 };
 
-#ifndef NEWDB
+#if 1
 struct grib_fieldset
 {
     grib_context* context;
@@ -1284,7 +1295,7 @@ struct grib_fieldset
 };
 #endif
 
-#ifdef NEWDB
+#if 0
 /* grib db */
 struct grib_db
 {
@@ -1596,11 +1607,14 @@ typedef struct j2k_encode_helper
 
 #include "eccodes_prototypes.h"
 
-
 #ifdef __cplusplus
 }
 #endif
+
 #endif
+
+
+
 /* This part is automatically generated by ./errors.pl, do not edit */
 #ifndef grib_errors_internal_H
 #define grib_errors_internal_H
