@@ -8,12 +8,14 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
 REDIRECT=/dev/null
 label="grib_filter_test"
 tempFilt="temp.$label.filt"
 tempGrib="temp.$label.grib"
+tempOut="temp.$label.txt"
+tempRef="temp.$label.ref"
 
 if [ -f ${data_dir}/geavg.t12z.pgrbaf108 ]; then
    tmpdata=grib_api.$$.grib
@@ -208,13 +210,96 @@ echo "Test MISSING"
 input="${data_dir}/reduced_gaussian_pressure_level.grib2"
 grib_check_key_equals $input scaleFactorOfFirstFixedSurface 0
 cat >$tempFilt <<EOF
-  set scaleFactorOfFirstFixedSurface = MISSING; # has to be uppercase
+  set scaleFactorOfFirstFixedSurface = MISSING;   # has to be uppercase
+  set scaledValueOfFirstFixedSurface = missing(); # has to have parens
   write;
 EOF
 ${tools_dir}/grib_filter -o $tempGrib $tempFilt $input
 grib_check_key_equals $tempGrib scaleFactorOfFirstFixedSurface MISSING
+grib_check_key_equals $tempGrib scaledValueOfFirstFixedSurface MISSING
+
+
+echo "Test from_scale_factor_scaled_value"
+# -----------------------------------------
+input="${samp_dir}/reduced_gg_pl_32_grib2.tmpl"
+cat >$tempFilt <<EOF
+  meta pl_scaled  from_scale_factor_scaled_value(one, pl);
+  print "pl_scaled=[pl_scaled%.2f]";
+EOF
+${tools_dir}/grib_filter $tempFilt $input > $tempOut
+
+cat >$tempRef <<EOF
+pl_scaled=2.00 2.70 3.60 4.00 4.50 5.00 6.00 6.40 
+7.20 7.50 8.00 9.00 9.00 9.60 10.00 10.80 
+10.80 12.00 12.00 12.00 12.80 12.80 12.80 12.80 
+12.80 12.80 12.80 12.80 12.80 12.80 12.80 12.80 
+12.80 12.80 12.80 12.80 12.80 12.80 12.80 12.80 
+12.80 12.80 12.80 12.80 12.00 12.00 12.00 10.80 
+10.80 10.00 9.60 9.00 9.00 8.00 7.50 7.20 
+6.40 6.00 5.00 4.50 4.00 3.60 2.70 2.00
+
+EOF
+diff $tempRef $tempOut
+
+
+echo "Test environment variables"
+# -----------------------------------------
+input="${samp_dir}/GRIB2.tmpl"
+cat >$tempFilt <<EOF
+  transient cds = environment_variable(CDS);
+  if (cds == 0) {
+    print "Either CDS is undefined or defined but equal to 0";
+  } else {
+    print "CDS is defined and equal to [cds]";
+  }
+EOF
+# No env var or zero
+${tools_dir}/grib_filter $tempFilt $input > $tempOut
+grep -q "undefined" $tempOut
+CDS=0 ${tools_dir}/grib_filter $tempFilt $input > $tempOut
+grep -q "defined but equal to 0" $tempOut
+# Set to a non-zero integer
+CDS=1 ${tools_dir}/grib_filter $tempFilt $input > $tempOut
+grep -q "defined and equal to 1" $tempOut
+CDS=-42 ${tools_dir}/grib_filter $tempFilt $input > $tempOut
+grep -q "defined and equal to -42" $tempOut
+
+
+echo "Test IEEE float overflow"
+# -----------------------------------------
+input="${samp_dir}/GRIB2.tmpl"
+cat >$tempFilt <<EOF
+  set values={ 5.4e100 };
+  write;
+EOF
+set +e
+${tools_dir}/grib_filter $tempFilt $input 2> $tempOut
+status=$?
+set -e
+[ $status -ne 0 ]
+grep -q "ECCODES ERROR.*Number is too large" $tempOut
+
+
+echo "Padded count for filenames"
+# -----------------------------------------
+input=${data_dir}/tigge_af_ecmwf.grib2
+tempDir=temp.${label}.dir
+rm -fr $tempDir
+mkdir -p $tempDir
+cd $tempDir
+cat >$tempFilt <<EOF
+  meta count_padded sprintf("%.2d", count);
+  write "out__[count_padded].grib";
+EOF
+${tools_dir}/grib_filter $tempFilt $input
+[ -f out__01.grib ]
+[ -f out__02.grib ]
+[ -f out__39.grib ]
+[ -f out__40.grib ]
+cd ..
+rm -rf $tempDir
 
 
 # Clean up
-rm -f $tempGrib $tempFilt
+rm -f $tempGrib $tempFilt $tempOut $tempRef
 rm -f ${data_dir}/formatint.rules ${data_dir}/binop.rules
