@@ -7,7 +7,7 @@
 # In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 
-. ./include.sh
+. ./include.ctest.sh
 
 if [ $ECCODES_ON_WINDOWS -eq 1 ]; then
     # m2-bash messes with the system path.
@@ -22,16 +22,11 @@ if [ $ECCODES_ON_WINDOWS -eq 1 ]; then
     export PATH=$PATH:$CONDA_PREFIX/Library/bin
 fi
 
-# Disable if autotools being used
-src_config=${src_dir}/config.h
-if [ -f ${src_config} ]; then
-    exit 0
-fi
-
 label="grib_to_netcdf_test"
 tempGrib=temp.${label}.grib
 tempNetcdf=temp.${label}.nc
 tempText=temp.${label}.txt
+tempDir=temp.${label}.dir
 
 have_netcdf4=0
 
@@ -130,5 +125,15 @@ grep -q "GRIB message 2 has different resolution" $tempText
 
 rm -f $tempGrib2
 
+echo "Test directory traversal ..."
+# ------------------------------------
+rm -f $tempNetcdf
+mkdir -p $tempDir/subdir
+cp ${data_dir}/regular_latlon_surface.grib2 $tempDir/subdir
+${tools_dir}/grib_to_netcdf -o $tempNetcdf $tempDir > $tempText
+[ -f "$tempNetcdf" ]
+grep -q "Processing input file .*/subdir/regular_latlon_surface.grib2" $tempText
+rm -rf $tempDir
+
 # Clean up
 rm -f $tempNetcdf $tempGrib $tempText
